@@ -300,6 +300,12 @@ class AdsAPI(object):
         args = {'fields': fields}
         return self.make_request(path, 'GET', args, batch=batch)
 
+    def get_adcreatives_by_adgroup(self, adgroup_id, fields, batch=False):
+        """Returns the fields for the given ad creative."""
+        path = '{0}/adcreatives'.format(adgroup_id)
+        args = {'fields': fields}
+        return self.make_request(path, 'GET', args, batch=batch)
+
     def get_adimages(self, account_id, hashes=None, batch=False):
         """Returns the ad images for the given ad account."""
         path = 'act_%s/adimages' % account_id
@@ -332,7 +338,7 @@ class AdsAPI(object):
         path = 'act_{0}/stats/{1}'.format(account_id, self.__parse_time(start_time))
         if end_time:
             path = path + '/{0}'.format(self.__parse_time(end_time))
-        return self.__page_results(path, args, batch)
+        return iterate_by_page(self.make_request(path, 'GET', args, batch))
 
     def get_stats_by_adcampaign(self, account_id, campaign_ids=None,
                                 batch=False, start_time=None, end_time=None):
@@ -790,7 +796,7 @@ class AdsAPI(object):
     # New API
     def update_adcampaign(self, campaign_id, name=None, campaign_status=None,
                           daily_budget=None, lifetime_budget=None,
-                          end_time=None, batch=False):
+                          start_time=None, end_time=None, batch=False):
         """Updates condition of the given ad campaign."""
         path = '%s' % campaign_id
         args = {}
@@ -802,6 +808,8 @@ class AdsAPI(object):
             args['daily_budget'] = daily_budget
         if lifetime_budget:
             args['lifetime_budget'] = lifetime_budget
+        if start_time:
+            args['start_time'] = start_time
         if end_time:
             args['end_time'] = end_time
         return self.make_request(path, 'POST', args, batch=batch)
@@ -813,6 +821,7 @@ class AdsAPI(object):
         return self.make_request(path, 'DELETE', batch=batch)
 
         logger.warn("This method is deprecated and is replaced with get_ads_pixels.")
+
     def create_adcreative(self, account_id, object_story_id=None, batch=False):
         """Creates an ad creative in the given ad account."""
         path = 'act_%s/adcreatives' % account_id
@@ -996,11 +1005,51 @@ class AdsAPI(object):
             return str(resp)
         return None
 
-    def __page_results(self, path, args, batch):
-        response = self.make_request(path, 'GET', args, batch=batch)
-        while True:
-            yield response
-            next_page = response.get('paging', {}).get('next', '')
-            if not next_page:
-                break
-            response = json.load(urllib2.urlopen(next_page))
+
+def iterate_by_page(response):
+    """
+    Generator function that will return one Facebook results page at a time
+
+    Note: Other than ensuring we don't crash, we accept facebook responses
+    regardless of whether they contain paging information or not.
+
+    Params:
+    response - A Facebook Ads API response body that includes pagination
+               sections.
+
+    Yields:
+    An unadultered page of Facebook response data, including data and any
+    provided pagination info.
+    """
+    response = response
+    while True:
+        yield response
+        next_page = response.get('paging', {}).get('next', '')
+        if not next_page:
+            break
+        response = json.load(urllib2.urlopen(next_page))
+
+
+def iterate_by_item(response):
+    """
+    Generator function that will return one Facebook results item at a time
+
+    Note: Other than ensuring we don't crash, we accept facebook responses
+    regardless of whether they contain paging information or not.
+
+    Params:
+    response - A Facebook Ads API response body that includes pagination
+               sections.
+
+    Yields:
+    An item from the Facebook response data. It will automatically navigate
+    over any additional pages that Facebook provides.
+    """
+    response = response
+    while True:
+        for r in response.get('data', []):
+            yield r
+        next_page = response.get('paging', {}).get('next', '')
+        if not next_page:
+            break
+        response = json.load(urllib2.urlopen(next_page))
